function [QT,QM]=huffcode(x);
//huffman coding of a sequence
// Calling Sequence
// [QT,QM]=huffcode(A)
// Parameters
// A: vector representing a input sequence. A is converted in the function to type INT. The elements of A must be greater or equal 1.
// QT: A string containing 1s and 0s. QT represents the binary output sequence of the huffman coded signal. QT can be converted into a scalar vector with str2code.
// QM: the huffman code table, containg symbols, bit sequences and number of bits of a symbol
// 
// Description
// The function converts the scalar input sequence (vector or matrix) into a compressed bit sequence. The bit sequence is represented by a string containing 1s and 0s.
// 
// huffcode requires the function "fasthist" and "huffman". The reverse operation is performed by the scilab function "huffdeco".
// 
// Examples
// // Generate a Testmatrix
//A=testmatrix('frk',10)+1;
//A=A(:).';
//[QT,QM]=huffcode(A);
//disp('compressed Bit sequence:');
//disp(QT);
//disp('Code Table:');
//disp(QM);
// See also
// fasthist
// huffman
// huffdeco
// Authors
// Dr. Andreas Geissler
// Holger Nahrstaedt



// HUFFCODE
//		[QT,QM]=HUFFCODE(X)
//		Huffman-Codierung des Vektors X
//		X	: Vektor mit positiven Werten
//		QM	: Codierungstabelle
//		QT	: Binres Ausgangssignal nach Codierung
//
//		Bentigt wird die Prozedur "HUFFMAN.M"


x=int(x);				        // Histogramm
if min(x)<=0,
	disp('Vector may contain only positive values  ...');
	disp('--------------------------------------------');
	return;
end

xmax=max(x);

h=fasthist(x);
h=full(h);
w=bool2s(h>0);
w=cumsum(w);
x=w(x);

[SB,H,L,QM]=huffman(h);			// Huffman Coding
					            // Code table = QM
S=[];
QTab=[];

for p=1:1:size(QM,1),
	K=strindex(QM(p,:),':');
	QTabakt=part(QM(p,1),K(1)+1:K(2)-1);		// Only Codes
	QTab=[QTab;QTabakt];
end

QT=strcat(QTab(x));

endfunction