function y=huffdeco(QT,QM);
// Decoding of a compressed bit sequence.
// Calling Sequence
// B=huffdeco(QT,QM);
// Parameters
// QT: the compressed bit sequence, represented by a string containing 1s and 0s
// QM: The huffman code table, containing symbols, bit sequence of a symbol and number of bits per symbol
// B: the decoded (uncompressed) sequence.
// Description
// huffdeco is the reverse operation to huffcode. The output arguments of huffcode can directly be used as input arguments for huffdeco
// Examples
// // Generate a Testmatrix
//A=testmatrix('frk',10)+1;
//A=A(:).';
//[QT,QM]=huffcode(A);
//disp('compressed Bit sequence:');
//disp(QT);
//disp('Code Table:');
// disp(QM);
// // Now, the reverse operation
// B=huffdeco(QT,QM);
// disp('Original:');
// disp(A);
// disp('Result after Uncompress:');
// disp(B);
// plot2d(B-A);
// See also
// huffcode
// huffman
// 
// Authors
// Dr. Andreas Geissler
// Holger Nahrstaedt



// HUFFDECODE
//		Y=HUFFDECODE(QT,QM);
//		Decoding of a huffman coded binary sequence
//		QT	:	The coded binary sequence as string
//		QM	:	The code table
//		Y	:	The decoded output signal

SB=[];							// Array which will contain symbols
CDTAB=[];						// String Array with Codes
for p=1:1:size(QM,1),			// Analyze the code table and build up Arrays
	K=strindex(QM(p,1),':');
	symbol=eval(part(QM(p,1),1:1:K(1)-1));
	SB=[SB,symbol];
	bits=part(QM(p,1),K(1)+1:1:K(2)-1);
	CDTAB=[CDTAB;bits];
end

kz=1:1:length(SB);
y=[];
spos=1;							// column counter for code table
zz=1;							// counter
kzakt=kz;						// selection index

useStringDecode=%f;

if useStringDecode then

      while zz<=length(QT),
	      qakt=part(QT,zz);
	      
								      // Walking through the tree
	      kzakt=kzakt(part(CDTAB(kzakt,1),spos)==qakt);
	      if length(kzakt)==1,
		      y=[y,SB(kzakt)];
		      kzakt=kz;
		      spos=1;
	      else
		      spos=spos+1;
	      end
	      zz=zz+1;
      end

else

    QT=str2code(QT);

    maxL=max(length(CDTAB));

    CDTAB2=ones(size(CDTAB,1),maxL)*-1;

    for i=1:size(CDTAB,1)
      CDTAB2(i,1:length(CDTAB(i)))=str2code(CDTAB(i))';
    end;

    while zz<=length(QT),
	    qakt=QT(zz);
	    kzakt=kzakt(CDTAB2(kzakt,spos)==qakt);
	    if length(kzakt)==1,
		    y=[y,SB(kzakt)];
		    kzakt=kz;
		    spos=1;
	    else
		    spos=spos+1;
	    end
	    zz=zz+1;
    end

end;

endfunction;